# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config merge_config
NULL

#' Amazon Connect Cases
#'
#' @description
#' With Amazon Connect Cases, your agents can track and manage customer
#' issues that require multiple interactions, follow-up tasks, and teams in
#' your contact center. A case represents a customer issue. It records the
#' issue, the steps and interactions taken to resolve the issue, and the
#' outcome. For more information, see [Amazon Connect
#' Cases](https://docs.aws.amazon.com/connect/latest/adminguide/cases.html)
#' in the *Amazon Connect Administrator Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectcases(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectcases()
#' svc$batch_get_field(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=connectcases_batch_get_field]{batch_get_field} \tab Returns the description for the list of fields in the request parameters\cr
#'  \link[=connectcases_batch_put_field_options]{batch_put_field_options} \tab Creates and updates a set of field options for a single select field in a Cases domain\cr
#'  \link[=connectcases_create_case]{create_case} \tab Creates a case in the specified Cases domain\cr
#'  \link[=connectcases_create_domain]{create_domain} \tab Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts\cr
#'  \link[=connectcases_create_field]{create_field} \tab Creates a field in the Cases domain\cr
#'  \link[=connectcases_create_layout]{create_layout} \tab Creates a layout in the Cases domain\cr
#'  \link[=connectcases_create_related_item]{create_related_item} \tab Creates a related item (comments, tasks, and contacts) and associates it with a case\cr
#'  \link[=connectcases_create_template]{create_template} \tab Creates a template in the Cases domain\cr
#'  \link[=connectcases_delete_domain]{delete_domain} \tab Deletes a Cases domain\cr
#'  \link[=connectcases_get_case]{get_case} \tab Returns information about a specific case if it exists\cr
#'  \link[=connectcases_get_case_event_configuration]{get_case_event_configuration} \tab Returns the case event publishing configuration\cr
#'  \link[=connectcases_get_domain]{get_domain} \tab Returns information about a specific domain if it exists\cr
#'  \link[=connectcases_get_layout]{get_layout} \tab Returns the details for the requested layout\cr
#'  \link[=connectcases_get_template]{get_template} \tab Returns the details for the requested template\cr
#'  \link[=connectcases_list_cases_for_contact]{list_cases_for_contact} \tab Lists cases for a given contact\cr
#'  \link[=connectcases_list_domains]{list_domains} \tab Lists all cases domains in the Amazon Web Services account\cr
#'  \link[=connectcases_list_field_options]{list_field_options} \tab Lists all of the field options for a field identifier in the domain\cr
#'  \link[=connectcases_list_fields]{list_fields} \tab Lists all fields in a Cases domain\cr
#'  \link[=connectcases_list_layouts]{list_layouts} \tab Lists all layouts in the given cases domain\cr
#'  \link[=connectcases_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for a resource\cr
#'  \link[=connectcases_list_templates]{list_templates} \tab Lists all of the templates in a Cases domain\cr
#'  \link[=connectcases_put_case_event_configuration]{put_case_event_configuration} \tab Adds case event publishing configuration\cr
#'  \link[=connectcases_search_cases]{search_cases} \tab Searches for cases within their associated Cases domain\cr
#'  \link[=connectcases_search_related_items]{search_related_items} \tab Searches for related items that are associated with a case\cr
#'  \link[=connectcases_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[=connectcases_untag_resource]{untag_resource} \tab Untags a resource\cr
#'  \link[=connectcases_update_case]{update_case} \tab Updates the values of fields on a case\cr
#'  \link[=connectcases_update_field]{update_field} \tab Updates the properties of an existing field\cr
#'  \link[=connectcases_update_layout]{update_layout} \tab Updates the attributes of an existing layout\cr
#'  \link[=connectcases_update_template]{update_template} \tab Updates the attributes of an existing template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectcases
#' @export
connectcases <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  config <- merge_config(
    config,
    list(
      credentials = credentials,
      endpoint = endpoint,
      region = region
    )
  )
  svc <- .connectcases$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.connectcases <- list()

.connectcases$operations <- list()

.connectcases$metadata <- list(
  service_name = "connectcases",
  endpoints = list("*" = list(endpoint = "cases.{region}.amazonaws.com", global = FALSE), "cn-*" = list(endpoint = "cases.{region}.amazonaws.com.cn", global = FALSE), "us-iso-*" = list(endpoint = "cases.{region}.c2s.ic.gov", global = FALSE), "us-isob-*" = list(endpoint = "cases.{region}.sc2s.sgov.gov", global = FALSE)),
  service_id = "ConnectCases",
  api_version = "2022-10-03",
  signing_name = "cases",
  json_version = "1.1",
  target_prefix = ""
)

.connectcases$service <- function(config = list()) {
  handlers <- new_handlers("restjson", "v4")
  new_service(.connectcases$metadata, handlers, config)
}
